@@ -36,7 +36,9 @@ class DeviceInformation:
         ASVersion = deviceInfo["ASVersion"]
         IPAddress = deviceInfo["IPAddress"]
         countryCode = deviceInfo["countryCode"]
+        gateway = deviceInfo["gateway"]
         hardwareModel = systemInfo["hardwareModel"]
+        deviceType = systemInfo["deviceType"]
         hardwareName = deviceInfo["hardwareName"]
         manufacturer = systemInfo["manufacturer"]
         modelNumber = deviceInfo["modelNumber"]
@@ -60,6 +62,8 @@ class DeviceInformation:
             epgCountryCode,
             hardwareModel,
             hardwareName,
+            deviceType,
+            gateway,
             manufacturer,
             modelNumber,
             serialNumber,
@@ -113,6 +117,16 @@ class Device:
         repr=True,
         compare=False,
     )
+    deviceType: str = field(
+        init=True,
+        repr=True,
+        compare=False,
+    )
+    gateway: str = field(
+        init=True,
+        repr=True,
+        compare=False,
+    )
     manufacturer: str = field(
         init=True,
         repr=True,
